@@ -34,12 +34,13 @@ def version():
         - 在`get_abs_order_type_ls`方法中处理str类型数据
         - 自动生成wiki打包autoWiki.py        # 2.1.12
 
-    # 2.2.0
+    # 2.2
         - 方法version转移到__init__.py中
         - 修改由`get_key_from_query_dc_or_self`引起的bug
         - 高级检索类增加`search_ls_dc`和`search_conf`两个参数
+        - 修改由于readme.md出错导致pypi上传失败的bug	# 2.2.2
     """
-    v = "2.2.1"     # 正式版: 2.2.0
+    v = "2.2.2"     # 正式版: 2.2.2
     return v
 
 
